Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2023)

Unified Diff: chrome/browser/resources/chromeos/emulator/bluetooth_settings.js

Issue 1999593002: Update chrome://device-emulator with newer Polymer guidelines (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: narrow mode drawer + webui safety Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/chromeos/emulator/bluetooth_settings.js
diff --git a/chrome/browser/resources/chromeos/emulator/bluetooth_settings.js b/chrome/browser/resources/chromeos/emulator/bluetooth_settings.js
index 377f73d7b9de9f830f45987c19c1486601e1d965..341375daef1c342dfd23ce8afe5aea1310d26845 100644
--- a/chrome/browser/resources/chromeos/emulator/bluetooth_settings.js
+++ b/chrome/browser/resources/chromeos/emulator/bluetooth_settings.js
@@ -54,12 +54,9 @@ var BluetoothDevice = function() {
Polymer({
is: 'bluetooth-settings',
- properties: {
- /**
- * The title to be displayed in a heading element for the element.
- */
- title: {type: String},
+ behaviors: [Polymer.NeonAnimatableBehavior],
+ properties: {
/**
* A set of bluetooth devices.
* @type !Array<!BluetoothDevice>
@@ -163,7 +160,7 @@ Polymer({
},
/**
* Called when the device edit modal is opened. Re-validates necessary input
* fields.
*/
editDialogOpened: function() {
@@ -190,7 +187,7 @@ Polymer({
},
/**
* Called on-input from an input element and on edit modal open.
* Validates whether or not the
* input's content matches a regular expression. If the input's value
* satisfies the regex, then make sure that the address is not already
@@ -457,15 +454,15 @@ Polymer({
},
/**
- * Shows a modal dialog to edit the selected device's properties.
+ * Shows a dialog to edit the selected device's properties.
* @param {Event} event Contains event data. |event.model.index| is the index
* of the item which the target is contained in.
*/
- showEditModal: function(event) {
+ showEditDialog: function(event) {
var index = event.model.index;
this.currentEditIndex = index;
this.currentEditableObject = this.devices[index];
- this.$.editModal.toggle();
+ this.$.editDialog.toggle();
},
/**
@@ -163,7 +160,7 @@ Polymer({
},
/**
- * Called when the device edit modal is opened. Re-validates necessary input
+ * Called when the device edit dialog is opened. Re-validates necessary input
* fields.
*/
@@ -190,7 +187,7 @@ Polymer({
},
/**
- * Called on-input from an input element and on edit modal open.
+ * Called on-input from an input element and on edit dialog open.
* Validates whether or not the
* input's content matches a regular expression. If the input's value

Powered by Google App Engine
This is Rietveld 408576698